@@ -4,7 +4,7 @@ use syn::{
 };
 
 pub(crate) enum NamedArgAttr {
-    Default(Expr),
+    Default(Box<Expr>),
     TryOptional,
 }
 
@@ -25,7 +25,7 @@ impl Parse for NamedArgAttr {
             let _: Token![=] = input.parse()?;
             let expr: Expr = input.parse()?;
 
-            Ok(NamedArgAttr::Default(expr))
+            Ok(NamedArgAttr::Default(Box::new(expr)))
         } else {
             Err(lookahead.error())
         }
